@@ -1,5 +1,6 @@
 # SPDX-License-Identifier: MIT
 
+from __future__ import annotations
 
 import copy
 import logging
@@ -8,6 +9,8 @@ import pathlib
 import sys
 import textwrap
 
+from typing import NoReturn
+
 import pyproject_hooks
 import pytest
 
@@ -248,10 +251,16 @@ def test_build_missing_backend(packages_path, distribution, tmpdir):
         builder.build(distribution, str(tmpdir))
 
 
-def test_check_dependencies(mocker, package_test_flit):
+def _nothing_installed(name: str) -> NoReturn:
+    raise _importlib.metadata.PackageNotFoundError(name)
+
+
+def test_check_dependencies(mocker, package_test_flit, monkeypatch):
     mocker.patch('pyproject_hooks.BuildBackendHookCaller.get_requires_for_build_sdist')
     mocker.patch('pyproject_hooks.BuildBackendHookCaller.get_requires_for_build_wheel')
 
+    monkeypatch.setattr(_importlib.metadata, 'distribution', _nothing_installed)
+
     builder = build.ProjectBuilder(package_test_flit)
 
     side_effects = [
@@ -416,7 +425,7 @@ def test_build_with_dep_on_console_script(tmp_path, demo_pkg_inline, capfd, mock
     with pytest.raises(SystemExit):
         main(['--wheel', '--outdir', str(tmp_path / 'dist'), str(tmp_path)])
 
-    out, err = capfd.readouterr()
+    out, _ = capfd.readouterr()
     lines = [line[3:] for line in out.splitlines() if line.startswith('BB ')]  # filter for our markers
     path_vars = lines[0].split(os.pathsep)
     which_detected = lines[1]
@@ -461,7 +470,7 @@ def test_prepare_not_dir_outdir(mocker, tmp_dir, package_test_flit):
     out = os.path.join(tmp_dir, 'out')
     with open(out, 'w', encoding='utf-8') as f:
         f.write('Not a directory')
-    with pytest.raises(build.BuildException, match='Build path .* exists and is not a directory'):
+    with pytest.raises(build.BuildException, match=r'Build path .* exists and is not a directory'):
         builder.prepare('wheel', out)
 
 
